@@ -249,9 +249,9 @@
     grSetMargin( 2, 1 );
     grGotobitmap( display->bitmap );
 
-    sprintf( buf,
-             "FreeType String Viewer - part of the FreeType %s test suite",
-             version );
+    snprintf( buf, sizeof ( buf ),
+              "FreeType String Viewer - part of the FreeType %s test suite",
+              version );
 
     grWriteln( buf );
     grLn();
@@ -402,7 +402,8 @@
       lcd_mode = " monochrome";
     }
 
-    sprintf( status.header_buffer, "mode changed to %s", lcd_mode );
+    snprintf( status.header_buffer, sizeof ( status.header_buffer ),
+              "mode changed to %s", lcd_mode );
     status.header = status.header_buffer;
   }
 
@@ -411,8 +412,8 @@
   event_color_change( void )
   {
     static int     i = 0;
-    unsigned char  r = i & 4 ? 0xff : 0;
-    unsigned char  g = i & 2 ? 0xff : 0;
+    unsigned char  r = i & 2 ? 0xff : 0;
+    unsigned char  g = i & 4 ? 0xff : 0;
     unsigned char  b = i & 1 ? 0xff : 0;
 
 
@@ -436,19 +437,6 @@
       i = 0;
   }
 
-  static void
-  event_gamma_change( double  delta )
-  {
-    display->gamma += delta;
-
-    if ( display->gamma > 3.0 )
-      display->gamma = 3.0;
-    else if ( display->gamma < 0.1 )
-      display->gamma = 0.1;
-
-    grSetTargetGamma( display->bitmap, display->gamma );
-  }
-
 
   static void
   event_size_change( int  delta )
@@ -499,8 +487,13 @@
     if ( *status.keys )
       event.key = grKEY( *status.keys++ );
     else
+    {
       grListenSurface( display->surface, 0, &event );
 
+      if ( event.type == gr_event_resize )
+        return ret;
+    }
+
     if ( event.key >= '1' && event.key < '1' + N_RENDER_MODES )
     {
       status.render_mode = (int)( event.key - '1' );
@@ -595,11 +588,11 @@
       goto Exit;
 
     case grKEY( 'g' ):
-      event_gamma_change( 0.1 );
+      FTDemo_Display_Gamma_Change( display,  1 );
       goto Exit;
 
     case grKEY( 'v' ):
-      event_gamma_change( -0.1 );
+      FTDemo_Display_Gamma_Change( display, -1 );
       goto Exit;
 
     case grKEY( 'n' ):
@@ -679,7 +672,8 @@
       "            `.afm' or `.pfm').\n"
       "\n" );
     fprintf( stderr,
-      "  -d WxHxD  Set the window width, height, and color depth\n"
+      "  -d WxH[xD]\n"
+      "            Set the window width, height, and color depth\n"
       "            (default: 640x480x24).\n"
       "  -k keys   Emulate sequence of keystrokes upon start-up.\n"
       "            If the keys contain `q', use batch mode.\n"
@@ -985,7 +979,6 @@
       event_text_change();
 
     event_color_change();
-    event_gamma_change( 0 );
 
     event_font_change( 0 );
     FTDemo_String_Set( handle, status.text );
